"use client"

import { motion } from 'framer-motion'
import { Calendar, Clock, User, Users, FileText } from 'lucide-react'
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from '@/components/ui/card'
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from '@/components/ui/table'
import { formatDate, formatTime } from '@/lib/utils'

interface Teacher {
  id: string
  name: string
  subject: string
  createdAt: Date
  updatedAt: Date
}

interface Slot {
  id: string
  teacherId: string
  date: Date
  time: string
  duration: number
  isAvailable: boolean
  createdAt: Date
  updatedAt: Date
  teacher: Teacher
}

interface Booking {
  id: string
  slotId: string
  parentName: string
  childName: string
  notes: string | null
  createdAt: Date
  updatedAt: Date
  slot: Slot
}

interface BookingListProps {
  bookings: Booking[]
}

export default function BookingList({ bookings }: BookingListProps) {
  // Group bookings by date
  const bookingsByDate = bookings.reduce((acc, booking) => {
    const dateStr = new Date(booking.slot.date).toDateString()
    if (!acc[dateStr]) {
      acc[dateStr] = []
    }
    acc[dateStr].push(booking)
    return acc
  }, {} as Record<string, Booking[]>)
  
  // Sort dates
  const sortedDates = Object.keys(bookingsByDate).sort((a, b) => {
    return new Date(a).getTime() - new Date(b).getTime()
  })
  
  // Sort bookings by time for each date
  sortedDates.forEach(date => {
    bookingsByDate[date].sort((a, b) => {
      return a.slot.time.localeCompare(b.slot.time)
    })
  })

  return (
    <motion.div
      initial={{ opacity: 0, y: 20 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.3 }}
    >
      <Card>
        <CardHeader>
          <CardTitle>Bookings</CardTitle>
          <CardDescription>
            View all parent evening appointment bookings.
          </CardDescription>
        </CardHeader>
        <CardContent>
          {bookings.length === 0 ? (
            <div className="text-center py-6 text-muted-foreground">
              No bookings have been made yet.
            </div>
          ) : (
            <div className="space-y-6">
              {sortedDates.map(dateStr => (
                <div key={dateStr} className="space-y-2">
                  <h3 className="text-lg font-medium flex items-center">
                    <Calendar className="h-5 w-5 mr-2 text-primary" />
                    {formatDate(new Date(dateStr))}
                  </h3>
                  <Table>
                    <TableHeader>
                      <TableRow>
                        <TableHead>Time</TableHead>
                        <TableHead>Teacher</TableHead>
                        <TableHead>Parent</TableHead>
                        <TableHead>Child</TableHead>
                        <TableHead>Notes</TableHead>
                      </TableRow>
                    </TableHeader>
                    <TableBody>
                      {bookingsByDate[dateStr].map((booking) => (
                        <TableRow key={booking.id}>
                          <TableCell className="font-medium flex items-center">
                            <Clock className="h-4 w-4 mr-2 text-muted-foreground" />
                            {formatTime(booking.slot.time)}
                          </TableCell>
                          <TableCell>
                            <div className="flex flex-col">
                              <span className="flex items-center">
                                <User className="h-4 w-4 mr-1 text-primary" />
                                {booking.slot.teacher.name}
                              </span>
                              <span className="text-xs text-muted-foreground">
                                {booking.slot.teacher.subject}
                              </span>
                            </div>
                          </TableCell>
                          <TableCell className="flex items-center">
                            <Users className="h-4 w-4 mr-2 text-muted-foreground" />
                            {booking.parentName}
                          </TableCell>
                          <TableCell>{booking.childName}</TableCell>
                          <TableCell className="max-w-xs truncate">
                            {booking.notes || '-'}
                          </TableCell>
                        </TableRow>
                      ))}
                    </TableBody>
                  </Table>
                </div>
              ))}
            </div>
          )}
        </CardContent>
      </Card>
    </motion.div>
  )
}